@@ -26,9 +26,9 @@ public:
   int getElementCount(void) { return 1; }
   void drawPrimitive(RenderContext* renderContext, int index);  
   GLbitfield getClearFlags(RenderContext* renderContext);
-  int getAttributeCount(AABox& bbox, AttribID attrib);
-  void getAttribute(AABox& bbox, AttribID attrib, int first, int count, double* result);
-  String  getTextAttribute(AABox& bbox, AttribID attrib, int index);
+  int getAttributeCount(SceneNode* subscene, AttribID attrib);
+  void getAttribute(SceneNode* subscene, AttribID attrib, int first, int count, double* result);
+  String  getTextAttribute(SceneNode* subscene, AttribID attrib, int index);
   void getTypeName(char* buffer, int buflen) { strncpy(buffer, "background", buflen); };
   SceneNode* getQuad() { return quad; };
 
