@@ -28,9 +28,9 @@ public:
   virtual void getTypeName(char* buffer, int buflen) { strncpy(buffer, "text", buflen); };
 
   int getElementCount(void){ return textArray.size(); }
-  int getAttributeCount(AABox& bbox, AttribID attrib);
-  void getAttribute(AABox& bbox, AttribID attrib, int first, int count, double* result);
-  String getTextAttribute(AABox& bbox, AttribID attrib, int index);
+  int getAttributeCount(SceneNode* subscene, AttribID attrib);
+  void getAttribute(SceneNode* subscene, AttribID attrib, int first, int count, double* result);
+  String getTextAttribute(SceneNode* subscene, AttribID attrib, int index);
     
   Vertex getPrimitiveCenter(int index) { return vertexArray[index]; }
 
